<?php

//include cookie code file
include './cookie.php';

class WebRss{
	
	public $cookies;
    public $userAgents;
	public $useLow = false;
	private $keywords = array();
	private $db;
	public $curl_opts = array();
	public $responseInfo;
	
    function __construct() {
		
		//create and save cookie
        $cookie_render = new  cookieRender;
        $cookie_render->CreateCookie();

        //get array cookie and user agent from txt file
        $this->cookies = array_filter(explode("\n", file_get_contents('list-cookies.txt')));
        $this->userAgents = array_filter(explode("\n", file_get_contents('list-user-agent.txt')));
		
		foreach (get_defined_constants() as $name => $val) {
			if (strpos($name, 'CURLOPT_') === 0) {
				$this->curl_opts[]= $name;
			}
		}
		
    }

    private $errors = [];

	public function process()

    {
		if( file_exists('cookies.txt') ){
			unlink('cookies.txt');
		}
		
        $url = isset($_SERVER['QUERY_STRING']) ? $_SERVER['QUERY_STRING'] : '';

        if($url == '') {

            $this->output([]);

        }
		
			
        $html = $this->useLow ? $this->getPageLowTime($url) : $this->getPage($url);
		
		$data = $this->getDataFromPage( $html );		
		
        $items = $this->parse($data);	
		
        $this->output($items);

    }
	
	public function getDataFromPage( $html )
	{
		$html = str_replace('\x22','"',$html);
		$html = str_replace('\x7b',"{",$html);
		$html = str_replace('\x7d',"}",$html);
		$html = str_replace('\x5b',"[",$html);
		$html = str_replace('\x5d',"]",$html);
		
		preg_match('/\"token\"\:\"(.*?)\"\,/i', $html , $token );		
		preg_match('/\{\"request\"\:(.*?)\,\"helpDialog/i',$html,$match);
		
		$url = 'https://trends.google.com/api/widgetdata/relatedsearches?req=' . urlencode($match[1]).'&token='.$token[1];
		$url = str_replace("%5C%5C","%5C",$url);
		
		return $this->getPage($url);
		
	}
	
	public function parse($html)

    {

        $items = array();

        try{
			
			$return = json_decode(ltrim($html,')]}\', '));
			
			if(empty($return->default->rankedList[1]->rankedKeyword)){
				throw new Exception('No Results found.');
			}
			
            foreach($return->default->rankedList[1]->rankedKeyword as $kword){
				$items[] = [
					'title'    => $kword->query,
					'category' => $kword->formattedValue
				];
			}

        }

        catch(Exception $e) {

            $this->errors[] = [

                'message' => $e->getMessage(),

            ];

        }
		
		$this->keywords = $items;
		
		return $items;

    }
	
	public function output($items){
        header('Content-Type: application/xml; charset=utf-8');
        $rss = '<?xml version="1.0" encoding="utf-8" ?><rss version="2.0"><channel><title>WebRss</title><link>http://example.com</link><description>Description</description><language>en</language>';
        
		foreach($items as $item) {
            $rss.= '<item><title>' . $item['title'] . '</title><category>' . $item['category'] . '</category></item>' . "\r\n";
        }
        $rss.= '</channel></rss>';
        die( $rss );

    }
	
	public function outputToCsv(){
		
		return $this->keywords;
		
	}
	
	public function getPage($url){   
		
		$ch = curl_init();	
		curl_setopt($ch, CURLOPT_COOKIEJAR, 'cookies.txt');
		curl_setopt($ch, CURLOPT_COOKIEFILE, 'cookies.txt');
		curl_setopt($ch, CURLOPT_HTTPHEADER, array(
			"Accept: application/html, text/plain, */*",
			"Accept-Language: en-US,en;q=0.8",
			"User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/59.0.3071.115 S",
			//"Host: trends.google.com"
		));
		curl_setopt($ch, CURLOPT_ENCODING, 'identity');
		curl_setopt($ch, CURLOPT_HEADER, false);
		curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_REFERER, "https://trends.google.com/");
		curl_setopt($ch, CURLOPT_VERBOSE, true);
		
		curl_setopt($ch, CURLOPT_URL, $url);
		
		if( in_array("CURLOPT_RESOLVE",$this->curl_opts) ){
			curl_setopt($ch, CURLOPT_RESOLVE, array("trends.google.com:443:172.217.26.4") );
		}
		
		$response = curl_exec($ch);
		$this->responseInfo = curl_getinfo($ch);
		$headerSize = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
		
		curl_close($ch);
		
		return $response;
		

    }
	
	
}?>